@@ -195,7 +195,7 @@ class Graph():
             # Get Operation
             op_name = torch_node.kind().split("::")[-1].lower()
             # Operation Parameters
-            op_params = {k: torch_node[k] for k in torch_node.attributeNames()} 
+            op_params = {k: getattr(torch_node, torch_node.kindOf(k))(k) for k in torch_node.attributeNames()}
             op = None
             if op_name in OP_DICT:
                 op= OP_DICT[op_name]
@@ -589,6 +589,7 @@ class Graph():
                     depend_cc_param_groups = param_groups[depend_cc.id]
                     depend_cc_param_groups['auxiliary_ccs'].append((cc.id, offset))
                     offset += depend_cc.num_groups
+        param_groups = dict(sorted(param_groups.items(), key=lambda kv:(kv[0], kv[1])))
         return param_groups.values()
     
 def pytorch_id(node):
